<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Controls_Manager as Controls_Manager;

class Elementor_Ovic_Blog extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_blog';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Blog', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-post-list';
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'general_section',
            array(
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            )
        );

        $this->add_control(
            'style',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Select style', 'kuteshop' ),
                'options' => kuteshop_preview_options( $this->get_name() ),
                'default' => 'style-01',
            ]
        );

        $this->add_control(
            'title',
            [
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'label'       => esc_html__( 'Title', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'subtitle',
            [
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'label'       => esc_html__( 'Subtitle', 'kuteshop' ),
                'condition'   => [
                    'style' => [ 'style-05', 'style-11' ],
                ],
            ]
        );

        $this->add_control(
            'decoration_color',
            [
                'label'     => esc_html__( 'Decoration Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    preg_replace( '/\s+/', ' ', '{{WRAPPER}} .ovic-title.style-01' ) => 'box-shadow: 0 -1px {{VALUE}} inset;',
                ],
                'condition' => [
                    'style' => [ 'style-01' ],
                ],
            ]
        );

        $this->add_control(
            'image_width',
            [
                'type'    => Controls_Manager::NUMBER,
                'label'   => esc_html__( 'Image width', 'kuteshop' ),
                'default' => 270,
            ]
        );

        $this->add_control(
            'image_height',
            [
                'type'    => Controls_Manager::NUMBER,
                'label'   => esc_html__( 'Image height', 'kuteshop' ),
                'default' => 257,
            ]
        );

        $this->add_control(
            'image_full_size',
            [
                'type'  => Controls_Manager::SWITCHER,
                'label' => esc_html__( 'Image Full size', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'target',
            [
                'label'   => esc_html__( 'Target', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'recent_post' => esc_html__( 'Latest', 'kuteshop' ),
                    'popularity'  => esc_html__( 'Popularity', 'kuteshop' ),
                    'date'        => esc_html__( 'Date', 'kuteshop' ),
                    'title'       => esc_html__( 'Title', 'kuteshop' ),
                    'post'        => esc_html__( 'Post', 'kuteshop' ),
                    'random'      => esc_html__( 'Random', 'kuteshop' ),
                ],
                'default' => 'recent_post',
            ]
        );

        if ( class_exists( 'ElementorPro\Modules\QueryControl\Module' ) ) {
            $this->add_control(
                'ids',
                [
                    'label'        => esc_html__( 'Search Post', 'kuteshop' ),
                    'type'         => ElementorPro\Modules\QueryControl\Module::QUERY_CONTROL_ID,
                    'options'      => [],
                    'label_block'  => true,
                    'multiple'     => true,
                    'autocomplete' => [
                        'object' => ElementorPro\Modules\QueryControl\Module::QUERY_OBJECT_POST,
                        'query'  => [
                            'post_type' => 'post'
                        ],
                    ],
                    'condition'    => [
                        'target' => 'post'
                    ],
                    'export'       => false,
                ]
            );
        } else {
            $this->add_control(
                'ids',
                [
                    'label'       => esc_html__( 'Post', 'kuteshop' ),
                    'type'        => Controls_Manager::TEXT,
                    'description' => esc_html__( 'Post ids', 'kuteshop' ),
                    'placeholder' => '1,2,3',
                    'label_block' => true,
                    'condition'   => [
                        'target' => 'post'
                    ],
                ]
            );
        }

        $this->add_control(
            'category',
            [
                'label'       => esc_html__( 'Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'meta_key'   => '',
                    'hide_empty' => true,
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target!' => 'post'
                ],
            ]
        );

        $this->add_control(
            'limit',
            [
                'label'       => esc_html__( 'Limit', 'kuteshop' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 6,
                'placeholder' => 6,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__( 'Order by', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''              => esc_html__( 'None', 'kuteshop' ),
                    'date'          => esc_html__( 'Date', 'kuteshop' ),
                    'ID'            => esc_html__( 'ID', 'kuteshop' ),
                    'author'        => esc_html__( 'Author', 'kuteshop' ),
                    'title'         => esc_html__( 'Title', 'kuteshop' ),
                    'modified'      => esc_html__( 'Modified', 'kuteshop' ),
                    'rand'          => esc_html__( 'Random', 'kuteshop' ),
                    'comment_count' => esc_html__( 'Comment count', 'kuteshop' ),
                    'menu_order'    => esc_html__( 'Menu order', 'kuteshop' ),
                    'post__in'      => esc_html__( 'Post In', 'kuteshop' ),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__( 'Sort order', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''     => esc_html__( 'None', 'kuteshop' ),
                    'DESC' => esc_html__( 'Descending', 'kuteshop' ),
                    'ASC'  => esc_html__( 'Ascending', 'kuteshop' ),
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'carousel_section',
            [
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'label' => esc_html__( 'Carousel settings', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'slide_nav',
            [
                'label'   => esc_html__( 'Nav style', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => kuteshop_nav_style(),
                'default' => '',
            ]
        );

        $this->carousel_settings( false );

        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        echo ovic_do_shortcode( $this->get_name(), $settings );
    }
}