<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Controls_Manager as Controls_Manager;

class Elementor_Ovic_Brands extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_brands';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Brand Tabs', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-product-tabs';
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'general_section',
            [
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'style',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Brands style', 'kuteshop' ),
                'options' => kuteshop_preview_options( $this->get_name() ),
                'default' => 'style-01',
            ]
        );

        $this->add_control(
            'active',
            [
                'label'   => esc_html__( 'Active', 'kuteshop' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1,
                'min'     => 1,
            ]
        );

        $this->add_control(
            'is_ajax',
            [
                'label' => esc_html__( 'Enable ajax', 'kuteshop' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'title',
            [
                'type'  => Controls_Manager::TEXT,
                'label' => esc_html__( 'Title', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'height',
            [
                'label'     => esc_html__( 'Logo Height', 'kuteshop' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tab-item a' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'space',
            [
                'label'      => esc_html__( 'Logo Spacing', 'kuteshop' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors'  => [
                    '{{WRAPPER}} .tab-item a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'tab_items',
            [
                'label' => esc_html__( 'Brand Content', 'kuteshop' ),
            ]
        );

        $repeater = new Elementor\Repeater();

        $repeater->start_controls_tabs( 'tab_repeater' );

        $repeater->start_controls_tab(
            'tab_title',
            [
                'label' => esc_html__( 'Title', 'kuteshop' ),
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__( 'Image', 'kuteshop' ),
                'type'  => Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'text_button',
            [
                'label'   => esc_html__( 'Text Link', 'kuteshop' ),
                'type'    => Controls_Manager::TEXT,
                'default' => 'SHOP THIS BRAND',
            ]
        );

        $repeater->add_control(
            'brand',
            [
                'label'       => esc_html__( 'Products Brand', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_brand',
                ] ),
                'label_block' => true,
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'tab_product',
            [
                'label' => esc_html__( 'Product', 'kuteshop' ),
            ]
        );

        $repeater->add_control(
            'target',
            [
                'label'   => esc_html__( 'Target', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'recent_products'       => esc_html__( 'Recent Products', 'kuteshop' ),
                    'featured_products'     => esc_html__( 'Feature Products', 'kuteshop' ),
                    'sale_products'         => esc_html__( 'Sale Products', 'kuteshop' ),
                    'best_selling_products' => esc_html__( 'Best Selling Products', 'kuteshop' ),
                    'top_rated_products'    => esc_html__( 'Top Rated Products', 'kuteshop' ),
                    'products'              => esc_html__( 'Products', 'kuteshop' ),
                    'product_category'      => esc_html__( 'Products Category', 'kuteshop' ),
                    'related_products'      => esc_html__( 'Products Related', 'kuteshop' ),
                ],
                'default' => 'recent_products',
            ]
        );

        if ( class_exists( 'ElementorPro\Modules\QueryControl\Module' ) ) {
            $repeater->add_control(
                'ids',
                [
                    'label'        => esc_html__( 'Search Product', 'kuteshop' ),
                    'type'         => ElementorPro\Modules\QueryControl\Module::QUERY_CONTROL_ID,
                    'options'      => [],
                    'label_block'  => true,
                    'multiple'     => true,
                    'autocomplete' => [
                        'object' => ElementorPro\Modules\QueryControl\Module::QUERY_OBJECT_POST,
                        'query'  => [
                            'post_type' => 'product'
                        ],
                    ],
                    'condition'    => [
                        'target' => 'products'
                    ],
                    'export'       => false,
                ]
            );
        } else {
            $repeater->add_control(
                'ids',
                [
                    'label'       => esc_html__( 'Product', 'kuteshop' ),
                    'type'        => Controls_Manager::TEXT,
                    'description' => esc_html__( 'Product ids', 'kuteshop' ),
                    'placeholder' => '1,2,3',
                    'label_block' => true,
                    'condition'   => [
                        'target' => 'products'
                    ],
                ]
            );
        }

        $repeater->add_control(
            'category',
            [
                'label'       => esc_html__( 'Products Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_cat',
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target!' => 'products'
                ],
            ]
        );

        $repeater->add_control(
            'limit',
            [
                'label'       => esc_html__( 'Limit', 'kuteshop' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 6,
                'placeholder' => 6,
            ]
        );

        $repeater->add_control(
            'orderby',
            [
                'label'   => esc_html__( 'Order by', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''              => esc_html__( 'None', 'kuteshop' ),
                    'date'          => esc_html__( 'Date', 'kuteshop' ),
                    'ID'            => esc_html__( 'ID', 'kuteshop' ),
                    'author'        => esc_html__( 'Author', 'kuteshop' ),
                    'title'         => esc_html__( 'Title', 'kuteshop' ),
                    'modified'      => esc_html__( 'Modified', 'kuteshop' ),
                    'rand'          => esc_html__( 'Random', 'kuteshop' ),
                    'comment_count' => esc_html__( 'Comment count', 'kuteshop' ),
                    'menu_order'    => esc_html__( 'Menu order', 'kuteshop' ),
                    'price'         => esc_html__( 'Price: low to high', 'kuteshop' ),
                    'price-desc'    => esc_html__( 'Price: high to low', 'kuteshop' ),
                    'rating'        => esc_html__( 'Average Rating', 'kuteshop' ),
                    'popularity'    => esc_html__( 'Popularity', 'kuteshop' ),
                    'post__in'      => esc_html__( 'Post In', 'kuteshop' ),
                    'most-viewed'   => esc_html__( 'Most Viewed', 'kuteshop' ),
                ],
            ]
        );

        $repeater->add_control(
            'order',
            [
                'label'   => esc_html__( 'Sort order', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''     => esc_html__( 'None', 'kuteshop' ),
                    'DESC' => esc_html__( 'Descending', 'kuteshop' ),
                    'ASC'  => esc_html__( 'Ascending', 'kuteshop' ),
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $this->add_control(
            'tabs',
            [
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ brand }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'product_section',
            [
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'label' => esc_html__( 'Product Settings', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'product_style',
            array(
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Product style', 'kuteshop' ),
                'options' => kuteshop_product_options( 'Shortcode', true ),
                'default' => 'style-01',
            )
        );

        $this->product_size_field();

        $this->add_control(
            'disable_labels',
            [
                'label'        => esc_html__( 'Disable Labels', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'labels-not-',
            ]
        );

        $this->add_control(
            'disable_rating',
            [
                'label'        => esc_html__( 'Disable Rating', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'rating-not-',
            ]
        );

        $this->add_control(
            'ensable_add_to_cart',
            [
                'label'        => esc_html__( 'Add to cart', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'add-to-cart-',
                'condition'    => [
                    'product_style' => 'style-02',
                ],
            ]
        );

        $this->add_control(
            'short_text',
            [
                'label'        => esc_html__( 'Short Title', 'kuteshop' ),
                'prefix_class' => 'short-text-',
                'type'         => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'overflow_visible',
            [
                'label' => esc_html__( 'Content Overflow', 'kuteshop' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->end_controls_section();

        $this->carousel_settings( [
            'tab'       => Controls_Manager::TAB_SETTINGS,
            'label'     => esc_html__( 'Carousel products', 'kuteshop' ),
        ] );

        $this->carousel_settings( [
            'tab'   => Controls_Manager::TAB_SETTINGS,
            'label' => esc_html__( 'Carousel Brand', 'kuteshop' ),
        ], 'tabs_' );
    }
}