<?php
if (!defined('ABSPATH')) {
    die('-1');
}

/**
 * Shortcode attributes
 * @var $atts
 * Shortcode class
 * @var $this "Shortcode_Ovic_Brands"
 * @version 1.0.0
 */
class Shortcode_Ovic_Brands extends Ovic_Addon_Shortcode
{
    /**
     * Shortcode name.
     *
     * @var  string
     */
    public $shortcode      = 'ovic_brands';
    public $is_woocommerce = true;
    public $default        = array(
        'style' => 'style-01',
        'short_text'  => '',
    );

    public function product_atts($atts, $tab)
    {
        $carousel                            = $this->generate_carousel($atts, 'slides_', false);
        $args                                = $tab;
        $args['carousel']                    = $carousel;
        $args['list_style']                  = 'owl';
        $args['disable_rating']              = $atts['disable_rating'];
        $args['slides_rows_space']           = $atts['slides_rows_space'];
        $args['product_style']               = $atts['product_style'];
        $args['product_image_size']          = $atts['product_image_size'];
        $args['product_custom_thumb_width']  = $atts['product_custom_thumb_width'];
        $args['product_custom_thumb_height'] = $atts['product_custom_thumb_height'];
        unset($args['title']);
        unset($args['image']);
        unset($args['_id']);

        return $args;
    }

    public function content($atts, $content = null)
    {
        $sections      = array();
        $css_class     = $this->main_class($atts, array(
            'ovic-tabs',
            'ovic-brands',
            $atts['style']
        ));
        if ($atts['short_text'] == 'yes') {
            $css_class .= ' short-text';
        }
        $is_ajax       = $atts['is_ajax'] == 'yes' ? 1 : 0;
        $tabs_carousel = $this->generate_carousel($atts, 'tabs_');
        ob_start();
        ?>
        <div class="<?php echo esc_attr($css_class); ?>">
            <?php if (!empty($atts['tabs'])): ?>
                <div class="tabs-head <?php if ($atts['style'] == 'style-01') {
                    echo esc_attr('nav-02 nav-top');
                } ?>">
                    <?php if (!empty($atts['title'])) : ?>
                        <h2 class="tab-title">
                            <?php if ($atts['style'] == 'style-03') {
                                $character = str_split($atts['title']);
                                $count     = 1;
                                foreach ($character as $value) {
                                    if ($value == ' ') {
                                        echo '<span class="space"></span>';
                                        $count++;
                                    } else {
                                        echo '<span class="text">'.esc_html($value).'</span>';
                                    }
                                }
                            } else {
                                echo '<span class="text">'.esc_html($atts['title']).'</span>';
                            } ?>
                        </h2>
                    <?php endif; ?>
                    <ul class="tabs-list owl-slick" <?php echo esc_attr($tabs_carousel); ?>>
                        <?php foreach ($atts['tabs'] as $key => $tab) : ?>
                            <?php
                            $count       = $key + 1;
                            $rendered    = array();
                            $shortcode   = array();
                            $class_items = array('tab-item');
                            $class_link  = array('tab-link');
                            $tab_id      = $tab['_id'].'-'.uniqid();

                            if ($count == $atts['active']) {

                                $class_items[] = 'active';
                                $class_link[]  = 'loaded';
                            }

                            if (!empty($tab['brand'])) {
                                $shortcode['ovic_brand'] = $tab;
                            }
                            $shortcode['ovic_products'] = $this->product_atts($atts, $tab);

                            $sections[$tab_id] = $shortcode;
                            $shortcode         = json_encode($shortcode);

                            $attributes = array(
                                'class'        => implode(' ', $class_link),
                                'href'         => '#tab-'.$tab_id,
                                'data-ajax'    => $is_ajax,
                                'data-animate' => 'fadeIn',
                            );
                            if ($is_ajax == 1) {
                                $attributes['data-section'] = $shortcode;
                            }

                            foreach ($attributes as $name => $value) {
                                if (is_array($value)) {
                                    $value = implode(' ', $value);
                                }
                                $rendered[] = sprintf('%1$s="%2$s"', $name, esc_attr($value));
                            }
                            ?>
                            <li class="<?php echo esc_attr(implode(' ', $class_items)); ?>">
                                <a <?php echo implode(' ', $rendered); ?>>
                                    <?php if (!empty($tab['image']['id'])) : ?>
                                        <span class="thumb">
                                            <?php echo wp_get_attachment_image($tab['image']['id'], 'full'); ?>
                                        </span>
                                    <?php endif; ?>
                                    <?php if (!empty($tab['title'])): ?>
                                        <span class="title"><?php echo esc_html($tab['title']); ?></span>
                                    <?php endif; ?>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>
                <div class="tabs-container">
                    <?php if (!empty($sections)): ?>
                        <?php
                        $count = 1;
                        foreach ($sections as $id => $section) : ?>
                            <?php
                            $active = array('tab-panel');
                            if ($count == $atts['active']) {
                                $active[] = 'active';
                            }
                            ?>
                            <div class="<?php echo esc_attr(implode(' ', $active)); ?>"
                                 id="tab-<?php echo esc_attr($id); ?>">
                                <?php
                                if ($is_ajax == true) :
                                    if ($count == $atts['active']) :
                                        foreach ($section as $tag => $shortcode) {
                                            echo ovic_do_shortcode($tag, $shortcode);
                                        }
                                    endif;
                                else :
                                    foreach ($section as $tag => $shortcode) {
                                        echo ovic_do_shortcode($tag, $shortcode);
                                    }
                                endif;
                                $count++;
                                ?>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
        <?php

        return ob_get_clean();
    }
}