<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Core\Schemes;
use Elementor\Controls_Manager as Controls_Manager;

class Elementor_Ovic_Category extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_category';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Category', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-product-categories';
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'general_section',
            array(
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            )
        );

        $this->add_control(
            'style',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Select style', 'kuteshop' ),
                'options' => kuteshop_preview_options( $this->get_name() ),
                'default' => 'style-01',
            ]
        );

        $this->add_control(
            'image',
            [
                'label'     => esc_html__( 'Image', 'kuteshop' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => [ 'style-01', 'style-02', 'style-03' ],
                ],
            ]
        );

        $this->add_control(
            'height',
            [
                'label'     => esc_html__( 'Image Height', 'kuteshop' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .ovic-category.style-01 .thumb img' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'style' => [ 'style-01' ]
                ],
            ]
        );

        $this->add_control(
            'sub_title',
            [
                'label'       => esc_html__( 'Sub Title', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-03' ]
                ],
            ]
        );

        $this->add_control(
            'selected_media',
            [
                'label'     => esc_html__( 'Media', 'kuteshop' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'icon'  => esc_html__( 'Icon', 'kuteshop' ),
                    'image' => esc_html__( 'Image', 'kuteshop' ),
                ],
                'default'   => 'icon',
                'condition' => [
                    'style' => [ 'style-05' ],
                ],
            ]
        );

        $this->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Icon', 'kuteshop' ),
                'type'             => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
                'condition'        => [
                    'style'          => [ 'style-05' ],
                    'selected_media' => [ 'icon' ],
                ],
            ]
        );

        $this->add_control(
            'selected_image',
            [
                'label'     => esc_html__( 'Image', 'kuteshop' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style'          => [ 'style-05' ],
                    'selected_media' => [ 'image' ],
                ],
            ]
        );

        $this->add_control(
            'title',
            [
                'label'       => esc_html__( 'Title', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'category_single',
            [
                'label'       => esc_html__( 'Products Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_cat',
                ] ),
                'multiple'    => false,
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-05' ],
                ],
            ]
        );

        $this->add_control(
            'image_effect',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Hover', 'kuteshop' ),
                'options' => kuteshop_effect_style(),
                'default' => '',
            ]
        );

        $this->add_control(
            'category',
            [
                'label'       => esc_html__( 'Products Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_cat',
                ] ),
                'multiple'    => true,
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-01', 'style-02', 'style-03', 'style-04' ],
                ],
            ]
        );

        $this->add_control(
            'link',
            [
                'type'        => Controls_Manager::URL,
                'label'       => esc_html__( 'Link', 'kuteshop' ),
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'style' => [ 'style-01', 'style-02', 'style-03', 'style-04' ],
                ],
            ]
        );

        $this->add_control(
            'text_button',
            [
                'type'      => Controls_Manager::TEXT,
                'label'     => esc_html__( 'Text button', 'kuteshop' ),
                'default'   => 'SHOP NOW',
                'condition' => [
                    'style' => [ 'style-01', 'style-02', 'style-03', 'style-04' ],
                ],
            ]
        );

        $this->add_control(
            'content_overflow',
            [
                'label'     => esc_html__( 'Content Overflow', 'kuteshop' ),
                'type'      => Controls_Manager::SWITCHER,
                'condition' => [
                    'style' => [ 'style-04' ]
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' => esc_html__( 'Style', 'kuteshop' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__( 'Title Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'scheme'    => [
                    'type'  => Schemes\Color::get_type(),
                    'value' => Schemes\Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Title Typography', 'kuteshop' ),
                'name'     => 'typography',
                'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'list_color',
            [
                'label'     => esc_html__( 'List Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'scheme'    => [
                    'type'  => Schemes\Color::get_type(),
                    'value' => Schemes\Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} ul.list-category a:not(.button):not(:hover)' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Typography::get_type(),
            [
                'label'    => esc_html__( 'Button Typography', 'kuteshop' ),
                'name'     => 'button_typography',
                'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} ul.list-category a.button',
            ]
        );

        $this->end_controls_section();

        $this->carousel_settings( [
            'tab'       => Controls_Manager::TAB_CONTENT,
            'label'     => esc_html__( 'Carousel settings', 'kuteshop' ),
            'condition' => [
                'style' => 'style-04',
            ],
        ] );
    }
}