<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Core\Schemes;
use Elementor\Controls_Manager as Controls_Manager;
use Elementor\Group_Control_Border;

class Elementor_Ovic_Newsletter extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_newsletter';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Newsletter', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-yoast';
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'general_section',
            array(
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            )
        );

        $this->add_control(
            'style',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Select style', 'kuteshop' ),
                'options' => kuteshop_preview_options( $this->get_name() ),
                'default' => 'style-01',
            ]
        );

        $this->add_control(
            'title',
            [
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__( 'Title', 'kuteshop' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'desc',
            [
                'type'      => Controls_Manager::TEXTAREA,
                'label'     => esc_html__( 'Description', 'kuteshop' ),
                'condition' => [
                    'style' => [ 'style-08' ],
                ],
            ]
        );

        $this->add_control(
            'form_id',
            [
                'type'        => Controls_Manager::SELECT,
                'label'       => esc_html__( 'Newsletter Form', 'kuteshop' ),
                'options'     => kuteshop_get_form_newsletter(),
                'default'     => '0',
                'description' => sprintf( '%s <a href="%s" target="_blank">%s</a>',
                    esc_html__( 'Add new form', 'kuteshop' ),
                    admin_url( 'admin.php?page=mailchimp-for-wp-forms&view=add-form' ),
                    esc_html__( 'Here!', 'kuteshop' )
                ),
            ]
        );

        $this->add_control(
            'placeholder',
            [
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__( 'Input Placeholder', 'kuteshop' ),
                'default'     => esc_html__( 'Your email address', 'kuteshop' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'button',
            [
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__( 'Button', 'kuteshop' ),
                'default'     => esc_html__( 'Subscribe', 'kuteshop' ),
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-01', 'style-03', 'style-05', 'style-06', 'style-07', 'style-09', 'style-10', 'style-11', 'style-12' ],
                ],
            ]
        );

        $this->add_control(
            'has_border',
            [
                'type'         => Controls_Manager::SWITCHER,
                'label'        => esc_html__( 'Has Border', 'kuteshop' ),
                'prefix_class' => 'border-',
                'condition'   => [
                    'style' => [ 'style-01', 'style-04', 'style-05', 'style-06', 'style-07', 'style-09', 'style-10', 'style-12' ],
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        echo ovic_do_shortcode( $this->get_name(), $settings );
    }
}