<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Controls_Manager as Controls_Manager;

class Elementor_Ovic_Products extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_products';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Products', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-woocommerce';
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'general_section',
            array(
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            )
        );

        $this->start_controls_tabs( 'tabs_general' );

        $this->start_controls_tab(
            'tab_general',
            [
                'label' => esc_html__( 'Settings', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'sc_title',
            [
                'type'      => Controls_Manager::TEXT,
                'label'     => esc_html__( 'Title', 'kuteshop' ),
                'condition' => [
                    'product_style' => 'style-02',
                ],
            ]
        );

        $this->add_control(
            'list_style',
            array(
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'List style', 'kuteshop' ),
                'options' => [
                    'none' => esc_html__( 'None', 'kuteshop' ),
                    'grid' => esc_html__( 'Bootstrap', 'kuteshop' ),
                    'owl'  => esc_html__( 'Carousel', 'kuteshop' ),
                ],
                'default' => 'owl',
            )
        );

        $this->add_control(
            'product_style',
            array(
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Product style', 'kuteshop' ),
                'options' => kuteshop_product_options( 'Shortcode', true ),
                'default' => 'style-01',
            )
        );

        $this->product_size_field();

        $this->add_control(
            'tab_color',
            [
                'label'     => esc_html__( 'Rating Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .star-rating::before'      => 'color: {{VALUE}};',
                    '{{WRAPPER}} .star-rating>span::before' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'disable_labels',
            [
                'label'        => esc_html__( 'Disable Labels', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'labels-not-',
            ]
        );

        $this->add_control(
            'disable_rating',
            [
                'label'        => esc_html__( 'Disable Rating', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'rating-not-',
            ]
        );

        $this->add_control(
            'short_text',
            [
                'label'        => esc_html__( 'Short Title', 'kuteshop' ),
                'prefix_class' => 'short-text-',
                'type'         => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'overflow_visible',
            [
                'label' => esc_html__( 'Content Overflow', 'kuteshop' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'border_hover',
            [
                'label'        => esc_html__( 'Border Hover', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'border-hover-',
                'condition'    => [
                    'product_style' => 'style-01',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_products',
            [
                'label' => esc_html__( 'Products', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'pagination',
            [
                'label'   => esc_html__( 'Pagination', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'none'      => esc_html__( 'None', 'kuteshop' ),
                    'view_all'  => esc_html__( 'View all', 'kuteshop' ),
                    'load_more' => esc_html__( 'Load More', 'kuteshop' ),
                    'infinite'  => esc_html__( 'Infinite Scrolling', 'kuteshop' ),
                ],
                'default' => 'none',
            ]
        );

        $this->add_control(
            'link',
            [
                'type'        => Controls_Manager::URL,
                'label'       => esc_html__( 'Link', 'kuteshop' ),
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'pagination' => 'view_all',
                ],
            ]
        );

        $this->add_control(
            'text_button',
            [
                'type'      => Controls_Manager::TEXT,
                'label'     => esc_html__( 'Text button', 'kuteshop' ),
                'default'   => 'VIEW ALL',
                'condition' => [
                    'pagination' => 'view_all',
                ],
            ]
        );

        $this->add_control(
            'target',
            [
                'label'   => esc_html__( 'Target', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'recent_products'       => esc_html__( 'Recent Products', 'kuteshop' ),
                    'featured_products'     => esc_html__( 'Feature Products', 'kuteshop' ),
                    'sale_products'         => esc_html__( 'Sale Products', 'kuteshop' ),
                    'best_selling_products' => esc_html__( 'Best Selling Products', 'kuteshop' ),
                    'top_rated_products'    => esc_html__( 'Top Rated Products', 'kuteshop' ),
                    'products'              => esc_html__( 'Products', 'kuteshop' ),
                    'product_category'      => esc_html__( 'Products Category', 'kuteshop' ),
                    'product_brand'         => esc_html__( 'Products Brand', 'kuteshop' ),
                    'related_products'      => esc_html__( 'Products Related', 'kuteshop' ),
                ],
                'default' => 'recent_products',
            ]
        );

        if ( class_exists( 'ElementorPro\Modules\QueryControl\Module' ) ) {
            $this->add_control(
                'ids',
                [
                    'label'        => esc_html__( 'Search Product', 'kuteshop' ),
                    'type'         => ElementorPro\Modules\QueryControl\Module::QUERY_CONTROL_ID,
                    'options'      => [],
                    'label_block'  => true,
                    'multiple'     => true,
                    'autocomplete' => [
                        'object' => ElementorPro\Modules\QueryControl\Module::QUERY_OBJECT_POST,
                        'query'  => [
                            'post_type' => 'product'
                        ],
                    ],
                    'condition'    => [
                        'target' => 'products'
                    ],
                    'export'       => false,
                ]
            );
        } else {
            $this->add_control(
                'ids',
                [
                    'label'       => esc_html__( 'Product', 'kuteshop' ),
                    'type'        => Controls_Manager::TEXT,
                    'description' => esc_html__( 'Product ids', 'kuteshop' ),
                    'placeholder' => '1,2,3',
                    'label_block' => true,
                    'condition'   => [
                        'target' => 'products'
                    ],
                ]
            );
        }

        $this->add_control(
            'category',
            [
                'label'       => esc_html__( 'Products Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => true,
                    'taxonomy'   => 'product_cat',
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target!' => 'products'
                ],
            ]
        );

        $this->add_control(
            'category_brand',
            [
                'label'       => esc_html__( 'Products Brand', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => true,
                    'taxonomy'   => 'product_brand',
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target' => 'product_brand'
                ],
            ]
        );

        $this->add_control(
            'limit',
            [
                'label'       => esc_html__( 'Limit', 'kuteshop' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 6,
                'placeholder' => 6,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__( 'Order by', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''              => esc_html__( 'None', 'kuteshop' ),
                    'date'          => esc_html__( 'Date', 'kuteshop' ),
                    'ID'            => esc_html__( 'ID', 'kuteshop' ),
                    'author'        => esc_html__( 'Author', 'kuteshop' ),
                    'title'         => esc_html__( 'Title', 'kuteshop' ),
                    'modified'      => esc_html__( 'Modified', 'kuteshop' ),
                    'rand'          => esc_html__( 'Random', 'kuteshop' ),
                    'comment_count' => esc_html__( 'Comment count', 'kuteshop' ),
                    'menu_order'    => esc_html__( 'Menu order', 'kuteshop' ),
                    'price'         => esc_html__( 'Price: low to high', 'kuteshop' ),
                    'price-desc'    => esc_html__( 'Price: high to low', 'kuteshop' ),
                    'rating'        => esc_html__( 'Average Rating', 'kuteshop' ),
                    'popularity'    => esc_html__( 'Popularity', 'kuteshop' ),
                    'post__in'      => esc_html__( 'Post In', 'kuteshop' ),
                    'most-viewed'   => esc_html__( 'Most Viewed', 'kuteshop' ),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__( 'Sort order', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''     => esc_html__( 'None', 'kuteshop' ),
                    'DESC' => esc_html__( 'Descending', 'kuteshop' ),
                    'ASC'  => esc_html__( 'Ascending', 'kuteshop' ),
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            'carousel_section',
            [
                'tab'       => Controls_Manager::TAB_SETTINGS,
                'label'     => esc_html__( 'Carousel settings', 'kuteshop' ),
                'condition' => [
                    'list_style' => 'owl',
                ],
            ]
        );

        $this->add_control(
            'slide_nav',
            [
                'label'   => esc_html__( 'Nav style', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => kuteshop_nav_style(),
                'default' => '',
            ]
        );

        $this->carousel_settings( false );

        $this->end_controls_section();

        $this->bootstrap_settings( [
            'tab'       => Controls_Manager::TAB_SETTINGS,
            'label'     => esc_html__( 'Bootstrap settings', 'kuteshop' ),
            'condition' => [
                'list_style' => 'grid',
            ],
        ] );
    }

    protected function render()
    {
        $settings        = $this->get_settings_for_display();
        $settings['_id'] = substr( $this->get_id_int(), 0, 3 );

        echo ovic_do_shortcode( $this->get_name(), $settings );
    }
}