<?php
if ( !defined( 'ABSPATH' ) ) {
    exit();
}

use Elementor\Core\Schemes;
use Elementor\Controls_Manager as Controls_Manager;

class Elementor_Ovic_Tabs extends Ovic_Widget_Elementor
{
    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'ovic_tabs';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__( 'Tabs', 'kuteshop' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'eicon-product-tabs';
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'general_section',
            [
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'General', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'style',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Tab style', 'kuteshop' ),
                'options' => kuteshop_preview_options( $this->get_name() ),
                'default' => 'style-01',
            ]
        );

        $this->add_control(
            'active',
            [
                'label'   => esc_html__( 'Active', 'kuteshop' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 1,
                'min'     => 1,
            ]
        );

        $this->add_control(
            'is_ajax',
            [
                'label' => esc_html__( 'Enable ajax', 'kuteshop' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'position',
            [
                'label'     => esc_html__( 'Position', 'kuteshop' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'start' => [
                        'icon'  => 'eicon-h-align-left',
                        'title' => esc_html__( 'Start', 'kuteshop' ),
                    ],
                    'end'   => [
                        'icon'  => 'eicon-h-align-right',
                        'title' => esc_html__( 'End', 'kuteshop' ),
                    ]
                ],
                'default'   => 'start',
                'toggle'    => false,
                'condition' => [
                    'style' => [ 'style-06' ],
                ],
            ]
        );

        $this->add_control(
            'tab_title',
            [
                'label'       => esc_html__( 'Title', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'selected_media',
            [
                'label'     => esc_html__( 'Title Media', 'kuteshop' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'image' => esc_html__( 'Image', 'kuteshop' ),
                    'icon'  => esc_html__( 'Icon', 'kuteshop' ),
                ],
                'default'   => 'icon',
                'condition' => [
                    'style' => [ 'style-02', 'style-03', 'style-06', 'style-13' ],
                ],
            ]
        );

        $this->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Title Icon', 'kuteshop' ),
                'type'             => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
                'condition'        => [
                    'style'          => [ 'style-02', 'style-03', 'style-06', 'style-13' ],
                    'selected_media' => 'icon'
                ],
            ]
        );

        $this->add_control(
            'image_icon',
            [
                'label'     => esc_html__( 'Title Image', 'kuteshop' ),
                'type'      => Controls_Manager::MEDIA,
                'condition' => [
                    'style'          => [ 'style-02', 'style-03', 'style-06', 'style-13' ],
                    'selected_media' => 'image'
                ],
            ]
        );

        $this->add_control(
            'tab_color',
            [
                'label'     => esc_html__( 'Tab Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ovic-tabs' => '--tab-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'decoration_color',
            [
                'label'     => esc_html__( 'Decoration Color', 'kuteshop' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .tabs-head' => 'box-shadow: 0 -1px {{VALUE}} inset;',
                ],
                'condition' => [
                    'style' => [ 'style-05' ],
                ],
            ]
        );

        $locations = array();
        $menus     = get_terms( 'nav_menu', array( 'hide_empty' => true ) );
        if ( !empty( $menus ) ) {
            foreach ( $menus as $menu ) {
                $locations[ $menu->slug ] = $menu->name;
            }
        }

        $this->add_control(
            'nav_menu',
            [
                'label_block' => true,
                'options'     => $locations,
                'type'        => Controls_Manager::SELECT2,
                'label'       => esc_html__( 'Menu', 'kuteshop' ),
                'description' => esc_html__( 'Select menu to display.', 'kuteshop' ),
                'condition'   => [
                    'style' => [ 'style-07' ],
                ],
            ]
        );

        $this->add_control(
            'category',
            [
                'label'       => esc_html__( 'List Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_cat',
                ] ),
                'multiple'    => true,
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-03', 'style-06', 'style-08', 'style-13' ],
                ],
            ]
        );

        $this->add_control(
            'bg_category',
            [
                'label'     => esc_html__( 'Background Category', 'kuteshop' ),
                'type'      => Controls_Manager::MEDIA,
                'condition' => [
                    'style' => [ 'style-03', 'style-13' ],
                ],
            ]
        );

        $this->add_control(
            'brand',
            [
                'label'       => esc_html__( 'List Brand', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => false,
                    'taxonomy'   => 'product_brand',
                ] ),
                'multiple'    => true,
                'label_block' => true,
                'condition'   => [
                    'style' => [ 'style-03', 'style-13' ],
                ],
            ]
        );

        $this->add_control(
            'date',
            [
                'type'           => Controls_Manager::DATE_TIME,
                'label'          => esc_html__( 'Countdown', 'kuteshop' ),
                'picker_options' => [
                    'dateFormat' => 'm/j/Y H:i:s',
                    'time_24hr'  => true,
                ],
                'condition'      => [
                    'style' => [ 'style-04' ],
                ],
            ]
        );

        $this->add_control(
            'tab_link',
            [
                'label'       => esc_html__( 'Button Link', 'kuteshop' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'style' => 'style-08',
                ],
            ]
        );

        $this->add_control(
            'tab_btn',
            [
                'type'      => Controls_Manager::TEXT,
                'label'     => esc_html__( 'Button Text', 'kuteshop' ),
                'condition' => [
                    'style' => 'style-08',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'tab_section',
            [
                'tab'   => Controls_Manager::TAB_CONTENT,
                'label' => esc_html__( 'Tab Content', 'kuteshop' ),
            ]
        );

        $repeater = new Elementor\Repeater();

        $repeater->start_controls_tabs( 'tab_repeater' );

        $repeater->start_controls_tab(
            'tab_title',
            [
                'label' => esc_html__( 'Title', 'kuteshop' ),
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label'       => esc_html__( 'Title', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Tab Title', 'kuteshop' ),
                'placeholder' => esc_html__( 'Tab Title', 'kuteshop' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label'   => esc_html__( 'Content', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'product'  => esc_html__( 'Products', 'kuteshop' ),
                    'template' => esc_html__( 'Template', 'kuteshop' ),
                    'link'     => esc_html__( 'Simple Link', 'kuteshop' ),
                ],
                'default' => 'product',
            ]
        );

        $repeater->add_control(
            'selected_media',
            [
                'label'   => esc_html__( 'Media', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'image' => esc_html__( 'Image', 'kuteshop' ),
                    'icon'  => esc_html__( 'Icon', 'kuteshop' ),
                ],
                'default' => 'image',
            ]
        );

        $repeater->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Icon', 'kuteshop' ),
                'type'             => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'fas fa-star',
                    'library' => 'fa-solid',
                ],
                'condition'        => [
                    'selected_media' => 'icon'
                ],
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label'     => esc_html__( 'Image', 'kuteshop' ),
                'type'      => Controls_Manager::MEDIA,
                'condition' => [
                    'selected_media' => 'image'
                ],
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'       => esc_html__( 'Link', 'kuteshop' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
                'condition'   => [
                    'content' => 'link',
                ],
            ]
        );

        $repeater->add_control(
            'class',
            [
                'label'       => esc_html__( 'Class', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'tab_template',
            [
                'label'     => esc_html__( 'Template', 'kuteshop' ),
                'condition' => [
                    'content' => 'template',
                ],
            ]
        );

        if ( class_exists( 'ElementorPro\Modules\QueryControl\Module' ) ) {
            $repeater->add_control(
                'template_id',
                [
                    'label'        => esc_html__( 'Template ID', 'kuteshop' ),
                    'type'         => ElementorPro\Modules\QueryControl\Module::QUERY_CONTROL_ID,
                    'options'      => [],
                    'label_block'  => true,
                    'multiple'     => false,
                    'autocomplete' => [
                        'object' => ElementorPro\Modules\QueryControl\Module::QUERY_OBJECT_POST,
                        'query'  => [
                            'post_type' => 'elementor_library'
                        ],
                    ],
                    'description'  => sprintf( '%s <a href="%s" target="_blank">%s</a>',
                        esc_html__( 'Create template from', 'kuteshop' ),
                        admin_url( 'edit.php?post_type=elementor_library&tabs_group=library' ),
                        esc_html__( 'Here', 'kuteshop' )
                    ),
                    'export'       => false,
                ]
            );
        } else {
            $repeater->add_control(
                'template_id',
                [
                    'label'       => esc_html__( 'Template ID', 'kuteshop' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                    'placeholder' => '1',
                    'description' => sprintf( '%s <a href="%s" target="_blank">%s</a>',
                        esc_html__( 'Create template from', 'kuteshop' ),
                        admin_url( 'edit.php?post_type=elementor_library&tabs_group=library' ),
                        esc_html__( 'Here', 'kuteshop' )
                    ),
                ]
            );
        }

        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'tab_product',
            [
                'label'     => esc_html__( 'Product', 'kuteshop' ),
                'condition' => [
                    'content' => 'product',
                ],
            ]
        );

        $repeater->add_control(
            'target',
            [
                'label'   => esc_html__( 'Target', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'recent_products'       => esc_html__( 'Recent Products', 'kuteshop' ),
                    'featured_products'     => esc_html__( 'Feature Products', 'kuteshop' ),
                    'sale_products'         => esc_html__( 'Sale Products', 'kuteshop' ),
                    'best_selling_products' => esc_html__( 'Best Selling Products', 'kuteshop' ),
                    'top_rated_products'    => esc_html__( 'Top Rated Products', 'kuteshop' ),
                    'products'              => esc_html__( 'Products', 'kuteshop' ),
                    'product_category'      => esc_html__( 'Products Category', 'kuteshop' ),
                    'product_brand'         => esc_html__( 'Products Brand', 'kuteshop' ),
                    'related_products'      => esc_html__( 'Products Related', 'kuteshop' ),
                ],
                'default' => 'recent_products',
            ]
        );

        if ( class_exists( 'ElementorPro\Modules\QueryControl\Module' ) ) {
            $repeater->add_control(
                'ids',
                [
                    'label'        => esc_html__( 'Search Product', 'kuteshop' ),
                    'type'         => ElementorPro\Modules\QueryControl\Module::QUERY_CONTROL_ID,
                    'options'      => [],
                    'label_block'  => true,
                    'multiple'     => true,
                    'autocomplete' => [
                        'object' => ElementorPro\Modules\QueryControl\Module::QUERY_OBJECT_POST,
                        'query'  => [
                            'post_type' => 'product'
                        ],
                    ],
                    'condition'    => [
                        'target' => 'products'
                    ],
                    'export'       => false,
                ]
            );
        } else {
            $repeater->add_control(
                'ids',
                [
                    'label'       => esc_html__( 'Product', 'kuteshop' ),
                    'type'        => Controls_Manager::TEXT,
                    'description' => esc_html__( 'Product ids', 'kuteshop' ),
                    'placeholder' => '1,2,3',
                    'label_block' => true,
                    'condition'   => [
                        'target' => 'products'
                    ],
                ]
            );
        }

        $repeater->add_control(
            'category',
            [
                'label'       => esc_html__( 'Products Category', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => true,
                    'taxonomy'   => 'product_cat',
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target!' => 'products'
                ],
            ]
        );

        $repeater->add_control(
            'category_brand',
            [
                'label'       => esc_html__( 'Products Brand', 'kuteshop' ),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_taxonomy( [
                    'hide_empty' => true,
                    'taxonomy'   => 'product_brand',
                ] ),
                'label_block' => true,
                'condition'   => [
                    'target' => 'product_brand'
                ],
            ]
        );

        $repeater->add_control(
            'limit',
            [
                'label'       => esc_html__( 'Limit', 'kuteshop' ),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 6,
                'placeholder' => 6,
            ]
        );

        $repeater->add_control(
            'orderby',
            [
                'label'   => esc_html__( 'Order by', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''              => esc_html__( 'None', 'kuteshop' ),
                    'date'          => esc_html__( 'Date', 'kuteshop' ),
                    'ID'            => esc_html__( 'ID', 'kuteshop' ),
                    'author'        => esc_html__( 'Author', 'kuteshop' ),
                    'title'         => esc_html__( 'Title', 'kuteshop' ),
                    'modified'      => esc_html__( 'Modified', 'kuteshop' ),
                    'rand'          => esc_html__( 'Random', 'kuteshop' ),
                    'comment_count' => esc_html__( 'Comment count', 'kuteshop' ),
                    'menu_order'    => esc_html__( 'Menu order', 'kuteshop' ),
                    'price'         => esc_html__( 'Price: low to high', 'kuteshop' ),
                    'price-desc'    => esc_html__( 'Price: high to low', 'kuteshop' ),
                    'rating'        => esc_html__( 'Average Rating', 'kuteshop' ),
                    'popularity'    => esc_html__( 'Popularity', 'kuteshop' ),
                    'post__in'      => esc_html__( 'Post In', 'kuteshop' ),
                    'most-viewed'   => esc_html__( 'Most Viewed', 'kuteshop' ),
                ],
            ]
        );

        $repeater->add_control(
            'order',
            [
                'label'   => esc_html__( 'Sort order', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''     => esc_html__( 'None', 'kuteshop' ),
                    'DESC' => esc_html__( 'Descending', 'kuteshop' ),
                    'ASC'  => esc_html__( 'Ascending', 'kuteshop' ),
                ],
            ]
        );

        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $this->add_control(
            'tabs',
            [
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'banner_section',
            [
                'tab'       => Controls_Manager::TAB_CONTENT,
                'label'     => esc_html__( 'Tab Banner', 'kuteshop' ),
                'condition' => [
                    'style' => [ 'style-02', 'style-03', 'style-05', 'style-06', 'style-07', 'style-13' ],
                ],
            ]
        );

        $this->add_control(
            'text_feature',
            [
                'label'       => esc_html__( 'Feature Text', 'kuteshop' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => 'Feature',
            ]
        );

        $this->add_control(
            'banner_top',
            [
                'type'  => Controls_Manager::GALLERY,
                'label' => esc_html__( 'Banner', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'top_link',
            [
                'label'       => esc_html__( 'Banner Link', 'kuteshop' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'banner_effect',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Banner Effect', 'kuteshop' ),
                'options' => kuteshop_effect_style(),
                'default' => '',
            ]
        );

        $this->add_control(
            'banner_left',
            [
                'type'  => Controls_Manager::GALLERY,
                'label' => esc_html__( 'Slide Banner', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'left_link',
            [
                'label'       => esc_html__( 'Slide Banner Link', 'kuteshop' ),
                'type'        => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'kuteshop' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'banner_slide_effect',
            [
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Slide Banner Effect', 'kuteshop' ),
                'options' => kuteshop_effect_style(),
                'default' => '',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'product_section',
            [
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'label' => esc_html__( 'Product Settings', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'product_style',
            array(
                'type'    => Controls_Manager::SELECT,
                'label'   => esc_html__( 'Product style', 'kuteshop' ),
                'options' => kuteshop_product_options( 'Shortcode', true ),
                'default' => 'style-01',
            )
        );

        $this->product_size_field();

        $this->add_control(
            'disable_labels',
            [
                'label'        => esc_html__( 'Disable Labels', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'labels-not-',
            ]
        );

        $this->add_control(
            'disable_rating',
            [
                'label'        => esc_html__( 'Disable Rating', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'rating-not-',
            ]
        );

        $this->add_control(
            'short_text',
            [
                'label'        => esc_html__( 'Short Title', 'kuteshop' ),
                'prefix_class' => 'short-text-',
                'type'         => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'overflow_visible',
            [
                'label' => esc_html__( 'Content Overflow', 'kuteshop' ),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'border_hover',
            [
                'label'        => esc_html__( 'Border Hover', 'kuteshop' ),
                'type'         => Controls_Manager::SWITCHER,
                'prefix_class' => 'border-hover-',
                'condition'    => [
                    'product_style' => 'style-01',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'carousel_section',
            [
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'label' => esc_html__( 'Carousel settings', 'kuteshop' ),
            ]
        );

        $this->add_control(
            'slide_nav',
            [
                'label'   => esc_html__( 'Nav style', 'kuteshop' ),
                'type'    => Controls_Manager::SELECT,
                'options' => kuteshop_nav_style(),
                'default' => '',
            ]
        );

        $this->carousel_settings( false );

        $this->end_controls_section();
    }
}